@@ -12,7 +12,7 @@ use Scalar::Util 'looks_like_number';
 use POSIX qw/ceil/;
 use JSON::Create '0.22', 'create_json';
 use JSON::Parse '0.42', 'parse_json';
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # eps is the allowed floating point error for summing the values of
 # the symbol table to ensure they form a probability distribution.
@@ -95,11 +95,13 @@ sub symbols
     # If this is supposed to be a probability distribution, check
     my $notprob = $options{notprob};
     if ($notprob) {
+	my $total = 0.0;
 	for my $k (keys %$s) {
 	    my $value = $s->{$k};
 	    if ($value < 0.0) {
 		croak "Negative weight $value for symbol $k";
 	    }
+	    $total += $value;
 	}
     }
     else {
@@ -221,13 +223,15 @@ sub xl
     my $s = $o->{s};
     croak "Bad object" unless $h && $s;
     my $len = 0.0;
+    my $total = 0.0;
     for my $k (keys %$h) {
 	$len += length ($h->{$k}) * $s->{$k};
+	$total += $s->{$k};
 	if ($o->{verbose}) {
 	    print "$k $h->{$k} $s->{$k} $len\n";
 	}
     }
-    return $len;
+    return $len / $total;
 }
 
 sub table
